@@ -54,7 +54,10 @@ public:
 
   /// Overidden to add a widget in the middle, under the menu, instead of replacing the whole contents.
   virtual void add(Gtk::Widget& child);
-   
+
+  /// For instance, to create bold primary text for a dialog box, without marking the markup for translation.
+  static Glib::ustring util_bold_message(const Glib::ustring& message);
+
 protected:
 
   virtual void init(); //Override to show().
@@ -70,24 +73,24 @@ protected:
   virtual void add_ui_from_string(const Glib::ustring& ui_description); //Convenience function
 
   virtual void on_hide(); //override.
-      
+
   //Signal handlers:
 
   //Menus:
   virtual void on_menu_help_about();
-  
+
   virtual void on_about_close();
 
 
   virtual void ui_hide();
   virtual void ui_bring_to_front();
-   
+
   virtual bool on_delete_event(GdkEventAny* event); //override
 
   //virtual void destroy_and_remove_from_list();
 
   //Member data:
-  
+
   //UIManager and Actions
   Glib::RefPtr<Gtk::UIManager> m_refUIManager;
   Glib::RefPtr<Gtk::ActionGroup> m_refFileActionGroup;
@@ -97,17 +100,17 @@ protected:
   //Member widgets:
   Gtk::VBox* m_pVBox;
   Gtk::VBox m_VBox_PlaceHolder;
-  
+
   //Gtk::MenuBar m_MenuBar;
   //Gtk::Menu m_Menu_File, m_Menu_Edit, m_Menu_Help;
 
   Gtk::HandleBox m_HandleBox_Toolbar;
   //Gtk::Toolbar m_Toolbar;
-  
+
   //All instances share 1 About box:
   static Gtk::Window* m_pAbout; //About box.
 
-  
+
   //typedef std::vector<poptOption> type_vecPoptOptions;
   //type_vecPoptOptions m_vecPoptOptions;
 };
