@@ -201,7 +201,6 @@ bool App_WithDoc::file_exists(const Glib::ustring& uri)
   {
     // Try to open the input file.
     Gnome::Vfs::Handle read_handle;
-#ifdef GLIBMM_EXCEPTIONS_ENABLED
     try
     {
       read_handle.open(uri, Gnome::Vfs::OPEN_READ);
@@ -213,11 +212,6 @@ bool App_WithDoc::file_exists(const Glib::ustring& uri)
     {
       return false; //It does not exist.
     }
-#else
-      std::auto_ptr<Gnome::Vfs::exception> error;
-      read_handle.open(uri, Gnome::Vfs::OPEN_READ, error);
-      if(error.get() != NULL) return false;
-#endif
   }
 }
 
