@@ -1,4 +1,5 @@
 #include <bakery/App/Dialog_OverwriteFile.h>
+#include <bakery/App/App_Gtk.h>
 #include <gtkmm/box.h>
 #include <libintl.h>
 
@@ -7,7 +8,7 @@ namespace Bakery
 
 
 Dialog_OverwriteFile::Dialog_OverwriteFile(const Glib::ustring& filepath)
-: Gtk::MessageDialog(gettext("<b>Overwrite File?</b>"), true /* use markup */, Gtk::MESSAGE_QUESTION, Gtk::BUTTONS_NONE)
+: Gtk::MessageDialog( App_Gtk::util_bold_message(gettext("Overwrite File?")), true /* use markup */, Gtk::MESSAGE_QUESTION, Gtk::BUTTONS_NONE)
 {
   set_title(""); //The HIG says that alert dialogs should not have titles. The default comes from the message type.
 
