@@ -30,7 +30,7 @@ AppExample::AppExample()
   m_Box.pack_start(m_Entry, Gtk::PACK_EXPAND_WIDGET);
 
   //Connect signals:
-  m_Entry.signal_changed().connect(SigC::slot(*this, &AppExample::on_Entry_changed));
+  m_Entry.signal_changed().connect(sigc::mem_fun(*this, &AppExample::on_Entry_changed));
  
   m_Box.show_all();
 }
@@ -75,12 +75,12 @@ void AppExample::on_Entry_changed()
   pDocument->set_something(m_Entry.get_text());
 }
 
-void AppExample::on_document_load()
+bool AppExample::on_document_load()
 {      
   //Show the data from the document in the GUI:
   //This would be simpler if we used a View - see the other App_WithDocView example.
   DocExample* pDocument = static_cast<DocExample*>(get_document());
   m_Entry.set_text(pDocument->get_something());
 
-  Bakery::App_WithDoc::on_document_load();
+  return Bakery::App_WithDoc::on_document_load();
 }
